@@ -11,19 +11,21 @@
 from .customizations import RequestAction
 from .ext import InvenioRequests
 from .proxies import (
+    current_event_type_registry,
     current_events_service,
-    current_registry,
+    current_request_type_registry,
     current_requests,
     current_requests_resource,
     current_requests_service,
 )
 
-__version__ = "0.3.7"
+__version__ = "0.3.10"
 
 __all__ = (
     "__version__",
+    "current_event_type_registry",
     "current_events_service",
-    "current_registry",
+    "current_request_type_registry",
     "current_requests_resource",
     "current_requests_service",
     "current_requests",
