@@ -6,6 +6,7 @@
 import { http } from "./config";
 import _isEmpty from "lodash/isEmpty";
 
+
 export class RequestLinksExtractor {
   #urls;
 
@@ -16,6 +17,10 @@ export class RequestLinksExtractor {
     this.#urls = request.links;
   }
 
+  get self_html() {
+    return this.#urls.self_html
+  }
+
   get timeline() {
     if (!this.#urls.timeline) {
       throw TypeError("Timeline link missing from resource.");
@@ -40,6 +45,7 @@ export class RequestLinksExtractor {
 
 export class InvenioRequestsAPI {
   #urls;
+
   constructor(requestLinksExtractor) {
     this.#urls = requestLinksExtractor;
   }
@@ -52,7 +58,7 @@ export class InvenioRequestsAPI {
     return await http.post(this.#urls.comments, payload);
   };
 
-  performAction = async (action, commentContent=null) => {
+  performAction = async (action, commentContent = null) => {
     let payload = {};
     if (!_isEmpty(commentContent)) {
       payload = {
