@@ -6,7 +6,11 @@
 
 export { default as RequestDetails } from "./request/RequestDetails";
 export { default as Timeline } from "./timeline/TimelineFeed";
-export { default as TimelineEvent } from "./timelineEvent/TimelineEvent";
+export { default as TimelineEvent } from "./timelineEvents/TimelineCommentEvent";
 export { default as RequestMetadata } from "./request/RequestMetadata";
 export { InvenioRequestsAPI } from "./api/api";
 export { InvenioRequestsApp } from "./InvenioRequestsApp";
+export { RequestActions } from "./request/actions/RequestActions";
+export { RequestAction } from "./request/actions/RequestAction";
+export { RequestActionController } from "./request/actions/RequestActionController";
+export { RequestActionContext } from "./request/actions/context";
