@@ -6,7 +6,7 @@
 
 import Overridable from "react-overridable";
 import Loader from "../components/Loader";
-import { RequestActionsPortal } from "./actions/RequestActions";
+import RequestActionsPortal from "./actions";
 import RequestDetails from "./RequestDetails";
 import React, { Component } from "react";
 import PropTypes from "prop-types";
@@ -19,12 +19,15 @@ export class Request extends Component {
   }
 
   render() {
-    const { request } = this.props;
+    const { request, updateRequestAfterAction } = this.props;
 
     return (
       <Overridable id="InvenioRequest.Request.layout">
         <Loader isLoading={isEmpty(request)}>
-          <RequestActionsPortal request={request} />
+          <RequestActionsPortal
+            request={request}
+            actionSuccessCallback={updateRequestAfterAction}
+          />
           <RequestDetails request={request} />
         </Loader>
       </Overridable>
@@ -35,6 +38,7 @@ export class Request extends Component {
 Request.propTypes = {
   request: PropTypes.object.isRequired,
   initRequest: PropTypes.func.isRequired,
+  updateRequestAfterAction: PropTypes.func.isRequired,
 };
 
 export default Overridable.component("InvenioRequests.Request", Request);
