@@ -7,6 +7,12 @@
 import React from "react";
 import ReactDOM from "react-dom";
 import { InvenioRequestsApp } from "./InvenioRequestsApp";
+import {
+  TimelineAcceptEvent,
+  TimelineCancelEvent,
+  TimelineDeclineEvent,
+  TimelineExpireEvent,
+} from "./timelineEvents";
 
 const requestDetailsDiv = document.getElementById("request-detail");
 const request = JSON.parse(requestDetailsDiv.dataset.record);
@@ -14,10 +20,18 @@ const defaultQueryParams = JSON.parse(
   requestDetailsDiv.dataset.defaultQueryConfig
 );
 
+const overriddenComponents = {
+  "TimelineEvent.layout.D": TimelineDeclineEvent,
+  "TimelineEvent.layout.A": TimelineAcceptEvent,
+  "TimelineEvent.layout.E": TimelineExpireEvent,
+  "TimelineEvent.layout.X": TimelineCancelEvent,
+};
+
 ReactDOM.render(
   <InvenioRequestsApp
     request={request}
     defaultQueryParams={defaultQueryParams}
+    overriddenCmps={overriddenComponents}
   />,
   requestDetailsDiv
 );
